==> vmaid-1.9.6.tar.gz: vmaid-1.9.6/src/icons.h <==
/*
    Video maid
    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __ICONS_H__
#define __ICONS_H__


#include "vmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:アイコン                                                                 *
*                                                                             *
******************************************************************************/
extern const gchar *vmaid16_xpm[];
extern const gchar *vmaid24_xpm[];
extern const gchar *vmaid32_xpm[];
extern const gchar *vmaid48_xpm[];
extern const gchar *tb_preview_xpm[];


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __ICONS_H__ */

==> vmaid-2.0.8.tar.gz: vmaid-2.0.8/src/icons.h <==
/*
    Video maid
    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __ICONS_H__
#define __ICONS_H__


#include "vmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:アイコン                                                                 *
*                                                                             *
******************************************************************************/
extern const gchar *vmaid16_xpm[];
extern const gchar *vmaid24_xpm[];
extern const gchar *vmaid32_xpm[];
extern const gchar *vmaid48_xpm[];
extern const gchar *preview16_xpm[];
extern const gchar *preview24_xpm[];
extern const gchar *merge16_xpm[];
extern const gchar *merge24_xpm[];
extern const gchar *change16_xpm[];
extern const gchar *change24_xpm[];
extern const gchar *reverse16_xpm[];
extern const gchar *reverse24_xpm[];
#if ! GTK_CHECK_VERSION(2,10,0)
extern const gchar *select_all16_xpm[];
extern const gchar *select_all24_xpm[];
#endif /* not GTK_CHECK_VERSION(2,10,0) */
extern const gchar *size16_xpm[];
extern const gchar *size24_xpm[];
#if ! GTK_CHECK_VERSION(2,6,0)
extern const gchar *about16_xpm[];
extern const gchar *about24_xpm[];
#endif /* not GTK_CHECK_VERSION(2,6,0) */


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __ICONS_H__ */
